#[non_exhaustive]pub enum ParseHandleError {
TooShort {
min: usize,
},
TooLong {
max: usize,
},
InvalidCharacter(char),
InvalidFormat,
InvalidPercentEncoding,
InvalidUtf8,
}Expand description
An invalid social media handle.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TooShort
The handle has fewer than the required number of characters.
TooLong
The handle exceeds the maximum number of characters.
InvalidCharacter(char)
The handle contains a character that the upstream does not permit.
InvalidFormat
The characters are individually permitted, but their arrangement is not.
InvalidPercentEncoding
A percent escape is incomplete or contains non-hexadecimal digits.
InvalidUtf8
The percent-decoded bytes are not UTF-8.